FakeCyton class

A simulated Cyton (+ Daisy) on the far end of a serial port: answers commands as firmware 3 does and streams a 10 Hz sine per channel (amplitude 10 µV × channel number) after b.

Constructors

FakeCyton(SerialTransport port, {bool daisy = true})

Properties

daisy → bool
final
hashCode → int
The hash code for this object.
no setterinherited
port → SerialTransport
final
received → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited